@@ -121,45 +121,45 @@ class Api :
         this.TDeviceSendCtrlCmd.restype=c_int;
         this.TDeviceSendCtrlCmd.argtypes=[c_void_p, c_char_p, c_char_p, c_int, c_int]
 
-        #TDEVICE_API TED_RESULT TDeviceReadRegValue(TDEVICE_HDL hdl, TED_REGADDR regAddr, TED_INT byteOffset, TED_INT readCnt, /*OUT*/ TED_REGVALUE* regValue);
+        #TDEVICE_API TED_BOOL TDeviceDD_DSIM_MipiReadReg(void* hdl, int dutIdx, int addr, int byteOffset, int readCount, unsigned char* buf, int bufMaxByteSize);
         this.TDeviceDD_DSIM_MipiReadReg = Load_DLL['TDeviceDD_DSIM_MipiReadReg']
         this.TDeviceDD_DSIM_MipiReadReg.restype=c_int;
-        this.TDeviceDD_DSIM_MipiReadReg.argtypes=[c_void_p, c_char, c_int, c_int, c_char_p]
+        this.TDeviceDD_DSIM_MipiReadReg.argtypes=[c_void_p, c_int, c_int, c_int, c_int, c_char_p, c_int]
 
-        #TDEVICE_API TED_RESULT TDeviceReadRegValue1Byte(TDEVICE_HDL hdl, TED_REGADDR regAddr, TED_INT byteOffset, /*OUT*/TED_REGVALUE* regValue);
+        #TDEVICE_API unsigned char TDeviceDD_DSIM_MipiReadReg1Byte(void* hdl, int dutIdx, int addr, int byteOffset);
         this.TDeviceDD_DSIM_MipiReadReg1Byte = Load_DLL['TDeviceDD_DSIM_MipiReadReg1Byte']
         this.TDeviceDD_DSIM_MipiReadReg1Byte.restype=c_int;
-        this.TDeviceDD_DSIM_MipiReadReg1Byte.argtypes=[c_void_p, c_char, c_int, c_char_p]
+        this.TDeviceDD_DSIM_MipiReadReg1Byte.argtypes=[c_void_p, c_int, c_int, c_int]
 
-        #TDEVICE_API TED_RESULT TDeviceWriteRegValue(TDEVICE_HDL hdl, TED_REGADDR regAddr, TED_INT byteOffset, TED_INT writeCnt,  TED_REGVALUE* regValue);
+        #TDEVICE_API TED_BOOL TDeviceDD_DSIM_MipiWriteReg(void* hdl, int dutIdx, int addr, int byteOffset, int writeCount, const unsigned char* buf);
         this.TDeviceDD_DSIM_MipiWriteReg = Load_DLL['TDeviceDD_DSIM_MipiWriteReg']
         this.TDeviceDD_DSIM_MipiWriteReg.restype=c_int;
-        this.TDeviceDD_DSIM_MipiWriteReg.argtypes=[c_void_p, c_char, c_int, c_int, c_char_p]
+        this.TDeviceDD_DSIM_MipiWriteReg.argtypes=[c_void_p, c_int, c_int, c_int, c_int, c_char_p]
 
-        #TDEVICE_API TED_RESULT TDeviceWriteRegValue1Byte(TDEVICE_HDL hdl, TED_REGADDR regAddr, TED_INT byteOffset, TED_REGVALUE regValue);
+        #TDEVICE_API TED_BOOL TDeviceDD_DSIM_MipiWriteReg1Byte(void* hdl, int dutIdx, int addr, int byteOffset, unsigned char data);
         this.TDeviceDD_DSIM_MipiWriteReg1Byte = Load_DLL['TDeviceDD_DSIM_MipiWriteReg1Byte']
         this.TDeviceDD_DSIM_MipiWriteReg1Byte.restype=c_int;
-        this.TDeviceDD_DSIM_MipiWriteReg1Byte.argtypes=[c_void_p, c_char, c_int, c_char]
+        this.TDeviceDD_DSIM_MipiWriteReg1Byte.argtypes=[c_void_p, c_int, c_int, c_int, c_char]
 
-        #TDEVICE_API TED_BOOL TDeviceDD_DSIM_MipiWriteReg39(TDEVICE_HDL hdl, unsigned char regAddr, int writeCnt, unsigned char* regValueArr);
+        #TDEVICE_API TED_BOOL TDeviceDD_DSIM_MipiWriteReg39(void* hdl, int dutIdx, int addr, int writeCount, const unsigned char* buf);
         this.TDeviceDD_DSIM_MipiWriteReg39 = Load_DLL['TDeviceDD_DSIM_MipiWriteReg39']
         this.TDeviceDD_DSIM_MipiWriteReg39.restype=c_int;
-        this.TDeviceDD_DSIM_MipiWriteReg39.argtypes=[c_void_p, c_char, c_int, c_char_p]
+        this.TDeviceDD_DSIM_MipiWriteReg39.argtypes=[c_void_p, c_int, c_int, c_int, c_char_p]
 
-        #TDEVICE_API TED_BOOL TDeviceDD_DSIM_MipiWriteReg15(TDEVICE_HDL hdl, unsigned char regAddr, unsigned char regValue);
+        #TDEVICE_API TED_BOOL TDeviceDD_DSIM_MipiWriteReg15(void* hdl, int dutIdx, int addr, unsigned char value);
         this.TDeviceDD_DSIM_MipiWriteReg15 = Load_DLL['TDeviceDD_DSIM_MipiWriteReg15']
         this.TDeviceDD_DSIM_MipiWriteReg15.restype=c_int;
-        this.TDeviceDD_DSIM_MipiWriteReg15.argtypes=[c_void_p, c_char, c_char]
+        this.TDeviceDD_DSIM_MipiWriteReg15.argtypes=[c_void_p, c_int, c_int, c_char]
 
-        #TDEVICE_API TED_BOOL TDeviceDD_DSIM_MipiWriteReg05(TDEVICE_HDL hdl, unsigned char regAddr);
+        #TDEVICE_API TED_BOOL TDeviceDD_DSIM_MipiWriteReg05(void* hdl, int dutIdx, int addr);
         this.TDeviceDD_DSIM_MipiWriteReg05 = Load_DLL['TDeviceDD_DSIM_MipiWriteReg05']
         this.TDeviceDD_DSIM_MipiWriteReg05.restype=c_int;
-        this.TDeviceDD_DSIM_MipiWriteReg05.argtypes=[c_void_p, c_char]
+        this.TDeviceDD_DSIM_MipiWriteReg05.argtypes=[c_void_p, c_int, c_int]
 
-        #TDEVICE_API TED_BOOL TDeviceDD_DSIM_MipiWriteReg07(TDEVICE_HDL hdl, unsigned char value);
+        #TDEVICE_API TED_BOOL TDeviceDD_DSIM_MipiWriteReg07(void* hdl, int dutIdx, int addr);
         this.TDeviceDD_DSIM_MipiWriteReg07 = Load_DLL['TDeviceDD_DSIM_MipiWriteReg07']
         this.TDeviceDD_DSIM_MipiWriteReg07.restype=c_int;
-        this.TDeviceDD_DSIM_MipiWriteReg07.argtypes=[c_void_p, c_char]
+        this.TDeviceDD_DSIM_MipiWriteReg07.argtypes=[c_void_p, c_int, c_int]
 
         #TDEVICE_API TED_RESULT TDeviceCatchPowerInfo(TDEVICE_HDL hdl, /*OUT*/struct TED_POWER_INFO* p_pwrinfo, TED_INT timeOut /*milisec */)
         this.TDeviceCatchPowerInfo = Load_DLL['TDeviceCatchPowerInfo']
