@@ -85,7 +85,10 @@ class TDevice :
     
     def SetTcLocalSave(this, boardID, bFlag) : 
         return this.__TDevice.SetTcLocalSave(boardID, bFlag)
-        
+    
+    def SysGetDefaultDutIndex(this) : 
+        return 0
+
     def SysGetDutIndexAllDeviceValue(this) : 
         return this.__TDevice.SysGetDutIndexAllDeviceValue()
 
